@@ -16,6 +16,52 @@
 from tencentcloud.common.abstract_model import AbstractModel
 
 
+class AddUserContactRequest(AbstractModel):
+    """AddUserContact request structure.
+
+    """
+
+    def __init__(self):
+        """
+        :param Name: Contact name, which needs to be unique and can contain 2-60 characters, supporting uppercase and lowercase letters, numbers, and underline “_”. It cannot start with “_”.
+        :type Name: str
+        :param ContactInfo: Email address, which can contain uppercase and lowercase letters, numbers, and underline “_”, and cannot start with “_”.
+        :type ContactInfo: str
+        :param Product: Service type, which is fixed to “mysql”.
+        :type Product: str
+        """
+        self.Name = None
+        self.ContactInfo = None
+        self.Product = None
+
+
+    def _deserialize(self, params):
+        self.Name = params.get("Name")
+        self.ContactInfo = params.get("ContactInfo")
+        self.Product = params.get("Product")
+
+
+class AddUserContactResponse(AbstractModel):
+    """AddUserContact response structure.
+
+    """
+
+    def __init__(self):
+        """
+        :param Id: The successfully added contact ID
+        :type Id: int
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
+        """
+        self.Id = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.Id = params.get("Id")
+        self.RequestId = params.get("RequestId")
+
+
 class ContactItem(AbstractModel):
     """Contact description.
 
@@ -121,7 +167,7 @@ class CreateMailProfileRequest(AbstractModel):
         :type ProfileType: str
         :param Product: Service type. Valid values: `mysql` (TencentDB for MySQL), `cynosdb` (TencentDB for CynosDB (compatible with MySQL)).
         :type Product: str
-        :param BindInstanceIds: Instance ID bound to the configuration, which is required when the configuration level is `Instance`.
+        :param BindInstanceIds: Instance ID bound to the configuration, which is set when the configuration level is "Instance". Only one instance can be bound at a time.
         :type BindInstanceIds: list of str
         """
         self.ProfileInfo = None
@@ -160,6 +206,58 @@ class CreateMailProfileResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class CreateSchedulerMailProfileRequest(AbstractModel):
+    """CreateSchedulerMailProfile request structure.
+
+    """
+
+    def __init__(self):
+        """
+        :param WeekConfiguration: Value range: 1-7, representing Monday to Sunday respectively.
+        :type WeekConfiguration: list of int
+        :param ProfileInfo: Email configurations
+        :type ProfileInfo: :class:`tencentcloud.dbbrain.v20191016.models.ProfileInfo`
+        :param ProfileName: Configuration name, which needs to be unique. For scheduled task reports, the name should be in the format of "scheduler_" + {instanceId}, such as "schduler_cdb-test".
+        :type ProfileName: str
+        :param BindInstanceId: Configure the instance ID that you need to generate the health report.
+        :type BindInstanceId: str
+        :param Product: Service type. Valid values: `mysql` (TencentDB for MySQL), `cynosdb` (TDSQL-C for MySQL). Default value: `mysql`.
+        :type Product: str
+        """
+        self.WeekConfiguration = None
+        self.ProfileInfo = None
+        self.ProfileName = None
+        self.BindInstanceId = None
+        self.Product = None
+
+
+    def _deserialize(self, params):
+        self.WeekConfiguration = params.get("WeekConfiguration")
+        if params.get("ProfileInfo") is not None:
+            self.ProfileInfo = ProfileInfo()
+            self.ProfileInfo._deserialize(params.get("ProfileInfo"))
+        self.ProfileName = params.get("ProfileName")
+        self.BindInstanceId = params.get("BindInstanceId")
+        self.Product = params.get("Product")
+
+
+class CreateSchedulerMailProfileResponse(AbstractModel):
+    """CreateSchedulerMailProfile response structure.
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeAllUserContactRequest(AbstractModel):
     """DescribeAllUserContact request structure.
 
@@ -167,7 +265,7 @@ class DescribeAllUserContactRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param Product: Service type. Valid values: `mysql` (TencentDB for MySQL), `cynosdb` (TencentDB for CynosDB (compatible with MySQL)).
+        :param Product: Service type, which is fixed to “mysql”.
         :type Product: str
         :param Names: An array of contact name. Fuzzy search is supported.
         :type Names: list of str
@@ -219,7 +317,7 @@ class DescribeAllUserGroupRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param Product: Service type. Valid values: `mysql` (TencentDB for MySQL), `cynosdb` (TencentDB for CynosDB (compatible with MySQL)).
+        :param Product: Service type, which is fixed to “mysql”.
         :type Product: str
         :param Names: An array of contact group name. Fuzzy search is supported.
         :type Names: list of str
@@ -464,6 +562,194 @@ class DescribeDBSpaceStatusResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeDiagDBInstancesRequest(AbstractModel):
+    """DescribeDiagDBInstances request structure.
+
+    """
+
+    def __init__(self):
+        """
+        :param IsSupported: Whether it is an instance supported by DBbrain. It is fixed to “true”.
+        :type IsSupported: bool
+        :param Product: Service type. Valid values: `mysql` (TencentDB for MySQL), `cynosdb` (TDSQL-C for MySQL). Default value: `mysql`.
+        :type Product: str
+        :param Offset: Pagination parameter indicating the offset.
+        :type Offset: int
+        :param Limit: Pagination parameter indicating the number of entries for each page.
+        :type Limit: int
+        :param InstanceNames: Query by instance name.
+        :type InstanceNames: list of str
+        :param InstanceIds: Query by instance ID.
+        :type InstanceIds: list of str
+        :param Regions: Query by region.
+        :type Regions: list of str
+        """
+        self.IsSupported = None
+        self.Product = None
+        self.Offset = None
+        self.Limit = None
+        self.InstanceNames = None
+        self.InstanceIds = None
+        self.Regions = None
+
+
+    def _deserialize(self, params):
+        self.IsSupported = params.get("IsSupported")
+        self.Product = params.get("Product")
+        self.Offset = params.get("Offset")
+        self.Limit = params.get("Limit")
+        self.InstanceNames = params.get("InstanceNames")
+        self.InstanceIds = params.get("InstanceIds")
+        self.Regions = params.get("Regions")
+
+
+class DescribeDiagDBInstancesResponse(AbstractModel):
+    """DescribeDiagDBInstances response structure.
+
+    """
+
+    def __init__(self):
+        """
+        :param TotalCount: Total Number of Instances
+        :type TotalCount: int
+        :param DbScanStatus: Status of all instance inspection. 0: all instance inspection enabled, 1: all instance inspection disabled
+        :type DbScanStatus: int
+        :param Items: Instance related information
+        :type Items: list of InstanceInfo
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
+        """
+        self.TotalCount = None
+        self.DbScanStatus = None
+        self.Items = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.TotalCount = params.get("TotalCount")
+        self.DbScanStatus = params.get("DbScanStatus")
+        if params.get("Items") is not None:
+            self.Items = []
+            for item in params.get("Items"):
+                obj = InstanceInfo()
+                obj._deserialize(item)
+                self.Items.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
+class DescribeHealthScoreRequest(AbstractModel):
+    """DescribeHealthScore request structure.
+
+    """
+
+    def __init__(self):
+        """
+        :param InstanceId: The instance ID that needs to obtain the health score
+        :type InstanceId: str
+        :param Time: Time to obtain the health score
+        :type Time: str
+        :param Product: Service type. Valid values: `mysql` (TencentDB for MySQL), `cynosdb` (TDSQL-C for MySQL (compatible with MySQL)). Default value: `mysql`.
+        :type Product: str
+        """
+        self.InstanceId = None
+        self.Time = None
+        self.Product = None
+
+
+    def _deserialize(self, params):
+        self.InstanceId = params.get("InstanceId")
+        self.Time = params.get("Time")
+        self.Product = params.get("Product")
+
+
+class DescribeHealthScoreResponse(AbstractModel):
+    """DescribeHealthScore response structure.
+
+    """
+
+    def __init__(self):
+        """
+        :param Data: Health score and deduction for exceptions
+        :type Data: :class:`tencentcloud.dbbrain.v20191016.models.HealthScoreInfo`
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
+        """
+        self.Data = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Data") is not None:
+            self.Data = HealthScoreInfo()
+            self.Data._deserialize(params.get("Data"))
+        self.RequestId = params.get("RequestId")
+
+
+class DescribeMailProfileRequest(AbstractModel):
+    """DescribeMailProfile request structure.
+
+    """
+
+    def __init__(self):
+        """
+        :param ProfileType: Configuration type. Valid values: "dbScan_mail_configuration" (email configuration of database inspection report), "scheduler_mail_configuration" (email configuration of scheduled task report).
+        :type ProfileType: str
+        :param Product: Service type. Valid values: `mysql` (TencentDB for MySQL), `cynosdb` (TDSQL-C for MySQL). Default value: `mysql`.
+        :type Product: str
+        :param Offset: Pagination offset
+        :type Offset: int
+        :param Limit: The number of results per page in paginated queries. Maximum value: 50
+        :type Limit: int
+        :param ProfileName: Query by the name of email configuration. The name of the regularly sent email configuration should be in the format of "scheduler_"+{instanceId}.
+        :type ProfileName: str
+        """
+        self.ProfileType = None
+        self.Product = None
+        self.Offset = None
+        self.Limit = None
+        self.ProfileName = None
+
+
+    def _deserialize(self, params):
+        self.ProfileType = params.get("ProfileType")
+        self.Product = params.get("Product")
+        self.Offset = params.get("Offset")
+        self.Limit = params.get("Limit")
+        self.ProfileName = params.get("ProfileName")
+
+
+class DescribeMailProfileResponse(AbstractModel):
+    """DescribeMailProfile response structure.
+
+    """
+
+    def __init__(self):
+        """
+        :param ProfileList: Email configuration details
+Note: this field may return `null`, indicating that no valid values can be obtained.
+        :type ProfileList: list of UserProfile
+        :param TotalCount: Total number of email templates
+Note: this field may return `null`, indicating that no valid values can be obtained.
+        :type TotalCount: int
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
+        """
+        self.ProfileList = None
+        self.TotalCount = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("ProfileList") is not None:
+            self.ProfileList = []
+            for item in params.get("ProfileList"):
+                obj = UserProfile()
+                obj._deserialize(item)
+                self.ProfileList.append(obj)
+        self.TotalCount = params.get("TotalCount")
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeSlowLogTimeSeriesStatsRequest(AbstractModel):
     """DescribeSlowLogTimeSeriesStats request structure.
 
@@ -791,6 +1077,55 @@ Note: this field may return null, indicating that no valid values can be obtaine
         self.Region = params.get("Region")
 
 
+class EventInfo(AbstractModel):
+    """Exception information
+
+    """
+
+    def __init__(self):
+        """
+        :param EventId: Event ID
+        :type EventId: int
+        :param DiagType: Diagnosis type
+        :type DiagType: str
+        :param StartTime: Start time
+        :type StartTime: str
+        :param EndTime: End time
+        :type EndTime: str
+        :param Outline: Summary
+        :type Outline: str
+        :param Severity: Severity, which can be divided into 5 levels: 1: fatal, 2: severe, 3: warning, 4: notice, 5: healthy.
+        :type Severity: int
+        :param ScoreLost: Deduction
+        :type ScoreLost: int
+        :param Metric: Reserved field
+        :type Metric: str
+        :param Count: The number of alarms
+        :type Count: int
+        """
+        self.EventId = None
+        self.DiagType = None
+        self.StartTime = None
+        self.EndTime = None
+        self.Outline = None
+        self.Severity = None
+        self.ScoreLost = None
+        self.Metric = None
+        self.Count = None
+
+
+    def _deserialize(self, params):
+        self.EventId = params.get("EventId")
+        self.DiagType = params.get("DiagType")
+        self.StartTime = params.get("StartTime")
+        self.EndTime = params.get("EndTime")
+        self.Outline = params.get("Outline")
+        self.Severity = params.get("Severity")
+        self.ScoreLost = params.get("ScoreLost")
+        self.Metric = params.get("Metric")
+        self.Count = params.get("Count")
+
+
 class GroupItem(AbstractModel):
     """Describe the group information.
 
@@ -816,6 +1151,40 @@ class GroupItem(AbstractModel):
         self.MemberCount = params.get("MemberCount")
 
 
+class HealthScoreInfo(AbstractModel):
+    """Obtain the details of the health score and deduction.
+
+    """
+
+    def __init__(self):
+        """
+        :param IssueTypes: Exception details
+        :type IssueTypes: list of IssueTypeInfo
+        :param EventsTotalCount: Total number of the exceptions
+        :type EventsTotalCount: int
+        :param HealthScore: Health score
+        :type HealthScore: int
+        :param HealthLevel: Health level, such as "HEALTH", "SUB_HEALTH", "RISK", "HIGH_RISK".
+        :type HealthLevel: str
+        """
+        self.IssueTypes = None
+        self.EventsTotalCount = None
+        self.HealthScore = None
+        self.HealthLevel = None
+
+
+    def _deserialize(self, params):
+        if params.get("IssueTypes") is not None:
+            self.IssueTypes = []
+            for item in params.get("IssueTypes"):
+                obj = IssueTypeInfo()
+                obj._deserialize(item)
+                self.IssueTypes.append(obj)
+        self.EventsTotalCount = params.get("EventsTotalCount")
+        self.HealthScore = params.get("HealthScore")
+        self.HealthLevel = params.get("HealthLevel")
+
+
 class InstanceConfs(AbstractModel):
     """Instance configuration.
 
@@ -825,12 +1194,173 @@ class InstanceConfs(AbstractModel):
         """
         :param DailyInspection: Whether to enable database inspection. Valid values: Yes/No.
         :type DailyInspection: str
+        :param OverviewDisplay: Whether to enable instance overview. Valid values: Yes/No.
+        :type OverviewDisplay: str
         """
         self.DailyInspection = None
+        self.OverviewDisplay = None
 
 
     def _deserialize(self, params):
         self.DailyInspection = params.get("DailyInspection")
+        self.OverviewDisplay = params.get("OverviewDisplay")
+
+
+class InstanceInfo(AbstractModel):
+    """Query the list of instances and return information about the instances.
+
+    """
+
+    def __init__(self):
+        """
+        :param InstanceId: Instance ID
+        :type InstanceId: str
+        :param InstanceName: Instance name
+        :type InstanceName: str
+        :param Region: The region where the instance belongs
+        :type Region: str
+        :param HealthScore: Health score
+        :type HealthScore: int
+        :param Product: Service
+        :type Product: str
+        :param EventCount: Number of exceptions
+        :type EventCount: int
+        :param InstanceType: Instance type. Valid values: 1: MASTER, 2: DR, 3: RO, 4: SDR
+        :type InstanceType: int
+        :param Cpu: Number of cores
+        :type Cpu: int
+        :param Memory: Memory in MB
+        :type Memory: int
+        :param Volume: Disk storage in GB
+        :type Volume: int
+        :param EngineVersion: Database version
+        :type EngineVersion: str
+        :param Vip: Private network address
+        :type Vip: str
+        :param Vport: Private network port
+        :type Vport: int
+        :param Source: Access source
+        :type Source: str
+        :param GroupId: Group ID
+        :type GroupId: str
+        :param GroupName: Group name
+        :type GroupName: str
+        :param Status: Instance status. Valid values: 0: Delivering, 1: Running, 4: Terminating, 5: Isolated
+        :type Status: int
+        :param UniqSubnetId: Subnet unified ID
+        :type UniqSubnetId: str
+        :param DeployMode: cdb (TencentDB instance) type
+        :type DeployMode: str
+        :param InitFlag: cdb (TencentDB instance) initialization flag. Valid values: 0: not initialized, 1: initialized
+        :type InitFlag: int
+        :param TaskStatus: Task status
+        :type TaskStatus: int
+        :param UniqVpcId: Unified VPC ID
+        :type UniqVpcId: str
+        :param InstanceConf: Instance inspection/overview status
+        :type InstanceConf: :class:`tencentcloud.dbbrain.v20191016.models.InstanceConfs`
+        :param DeadlineTime: Resource expiration time
+        :type DeadlineTime: str
+        :param IsSupported: Whether it is an instance supported by DBbrain.
+        :type IsSupported: bool
+        :param SecAuditStatus: The status of instance security audit log. ON: enabled, OFF: disabled.
+        :type SecAuditStatus: str
+        :param AuditPolicyStatus: The status of instance audit log. ALL_AUDIT: full audit is enabled, RULE_AUDIT: rule audit is enabled, UNBOUND: audit is disabled.
+        :type AuditPolicyStatus: str
+        :param AuditRunningStatus: The running status of instance audit log. normal: running, paused: suspension due to arrears
+        :type AuditRunningStatus: str
+        """
+        self.InstanceId = None
+        self.InstanceName = None
+        self.Region = None
+        self.HealthScore = None
+        self.Product = None
+        self.EventCount = None
+        self.InstanceType = None
+        self.Cpu = None
+        self.Memory = None
+        self.Volume = None
+        self.EngineVersion = None
+        self.Vip = None
+        self.Vport = None
+        self.Source = None
+        self.GroupId = None
+        self.GroupName = None
+        self.Status = None
+        self.UniqSubnetId = None
+        self.DeployMode = None
+        self.InitFlag = None
+        self.TaskStatus = None
+        self.UniqVpcId = None
+        self.InstanceConf = None
+        self.DeadlineTime = None
+        self.IsSupported = None
+        self.SecAuditStatus = None
+        self.AuditPolicyStatus = None
+        self.AuditRunningStatus = None
+
+
+    def _deserialize(self, params):
+        self.InstanceId = params.get("InstanceId")
+        self.InstanceName = params.get("InstanceName")
+        self.Region = params.get("Region")
+        self.HealthScore = params.get("HealthScore")
+        self.Product = params.get("Product")
+        self.EventCount = params.get("EventCount")
+        self.InstanceType = params.get("InstanceType")
+        self.Cpu = params.get("Cpu")
+        self.Memory = params.get("Memory")
+        self.Volume = params.get("Volume")
+        self.EngineVersion = params.get("EngineVersion")
+        self.Vip = params.get("Vip")
+        self.Vport = params.get("Vport")
+        self.Source = params.get("Source")
+        self.GroupId = params.get("GroupId")
+        self.GroupName = params.get("GroupName")
+        self.Status = params.get("Status")
+        self.UniqSubnetId = params.get("UniqSubnetId")
+        self.DeployMode = params.get("DeployMode")
+        self.InitFlag = params.get("InitFlag")
+        self.TaskStatus = params.get("TaskStatus")
+        self.UniqVpcId = params.get("UniqVpcId")
+        if params.get("InstanceConf") is not None:
+            self.InstanceConf = InstanceConfs()
+            self.InstanceConf._deserialize(params.get("InstanceConf"))
+        self.DeadlineTime = params.get("DeadlineTime")
+        self.IsSupported = params.get("IsSupported")
+        self.SecAuditStatus = params.get("SecAuditStatus")
+        self.AuditPolicyStatus = params.get("AuditPolicyStatus")
+        self.AuditRunningStatus = params.get("AuditRunningStatus")
+
+
+class IssueTypeInfo(AbstractModel):
+    """Metric information
+
+    """
+
+    def __init__(self):
+        """
+        :param IssueType: Metric categories: AVAILABILITY, MAINTAINABILITY, PERFORMANCE, and RELIABILITY
+        :type IssueType: str
+        :param Events: Exception
+        :type Events: list of EventInfo
+        :param TotalCount: Total number of the exceptions
+        :type TotalCount: int
+        """
+        self.IssueType = None
+        self.Events = None
+        self.TotalCount = None
+
+
+    def _deserialize(self, params):
+        self.IssueType = params.get("IssueType")
+        if params.get("Events") is not None:
+            self.Events = []
+            for item in params.get("Events"):
+                obj = EventInfo()
+                obj._deserialize(item)
+                self.Events.append(obj)
+        self.TotalCount = params.get("TotalCount")
 
 
 class MailConfiguration(AbstractModel):
@@ -842,7 +1372,7 @@ class MailConfiguration(AbstractModel):
         """
         :param SendMail: Whether to enable email sending. Valid values: 0 (No), 1 (Yes).
         :type SendMail: int
-        :param Region: Region configuration, such as "ap-guangzhou", "ap-shanghai".
+        :param Region: Region configuration, such as "ap-guangzhou", "ap-shanghai". For the inspection email sending template, configure the region where you need to send the inspection email. For the subscription email sending template, configure the region to which the current subscribed instance belongs.
         :type Region: list of str
         :param HealthStatus: Sending a report with the specified health level, such as "HEALTH", "SUB_HEALTH", "RISK", "HIGH_RISK".
         :type HealthStatus: list of str
@@ -1253,4 +1783,43 @@ class TimeSlice(AbstractModel):
 
     def _deserialize(self, params):
         self.Count = params.get("Count")
-        self.Timestamp = params.get("Timestamp")
\ No newline at end of file
+        self.Timestamp = params.get("Timestamp")
+
+
+class UserProfile(AbstractModel):
+    """Information configured by user, including email configuration.
+
+    """
+
+    def __init__(self):
+        """
+        :param ProfileId: Configured ID
+Note: this field may return `null`, indicating that no valid values can be obtained.
+        :type ProfileId: str
+        :param ProfileType: Configuration type
+Note: this field may return `null`, indicating that no valid values can be obtained.
+        :type ProfileType: str
+        :param ProfileLevel: Configuration level. Valid values: “User” or “Instance”
+Note: this field may return `null`, indicating that no valid values can be obtained.
+        :type ProfileLevel: str
+        :param ProfileName: Configuration name
+Note: this field may return `null`, indicating that no valid values can be obtained.
+        :type ProfileName: str
+        :param ProfileInfo: Configuration details
+        :type ProfileInfo: :class:`tencentcloud.dbbrain.v20191016.models.ProfileInfo`
+        """
+        self.ProfileId = None
+        self.ProfileType = None
+        self.ProfileLevel = None
+        self.ProfileName = None
+        self.ProfileInfo = None
+
+
+    def _deserialize(self, params):
+        self.ProfileId = params.get("ProfileId")
+        self.ProfileType = params.get("ProfileType")
+        self.ProfileLevel = params.get("ProfileLevel")
+        self.ProfileName = params.get("ProfileName")
+        if params.get("ProfileInfo") is not None:
+            self.ProfileInfo = ProfileInfo()
+            self.ProfileInfo._deserialize(params.get("ProfileInfo"))
\ No newline at end of file
